!=======================================================================
!=======================================================================
      SUBROUTINE FITEBOP (DATA,DTYPE,NDATA,NLR,NMIN,V,VARY,LDTYPE,ITER,
     &                    CHISQ,VERR,ERROR,NSINE,PSINE,NPOLY,PPOLY,NL3,
     &                    NECW,NESW,NUMINT,NINTERVAL)
            ! This subroutine calls the  MRQMIN  algorithm (Press et al,
            ! 1992, Numerical recipes in FORTRAN 77, p.678)  which finds
            ! the best-fitting EBOP model for the data using the
            ! Levenberg-Marquardt optimisation method.
            ! Unfortunately I have had to use a COMMON block here to
            ! avoid passing parameters through MRQMIN and related code.
      implicit none
      real*8 DATA(3,999999)               ! IN: Observational data
      integer DTYPE(999999)               ! IN: Types of datapoints
      integer NDATA,NLR,NMIN              ! IN: Numbers of datapoints
      real*8 V(67)                        ! IN: EBOP parameter values
      integer VARY(67)                    ! IN: Whether parameters vary
      integer LDTYPE(2)                   ! IN: Type of LD law for stars
      integer NSINE,NL3,NECW,NESW         ! IN: Numbers of sines and L3s
      integer PSINE(5)                    ! IN: Which par for each sine
      integer NPOLY,PPOLY(5)              ! IN: Similar for polynomials
      integer NUMINT                      ! IN: Number of numerical ints
      real*8 NINTERVAL                    ! IN: Time interval for numint
      integer ITER                        ! OUT: Number of iterations
      real*8 CHISQ                        ! OUT: Reduced chi-squared
      real*8 VERR(67)                     ! OUT: Formal parameter errors
      integer ERROR                       ! OUT: Whether fit successful
      real*8 X(999999),Y(999999),SIG(999999) ! LOCAL: data for MRQMIN
      real*8 LAMBDA                       ! LOCAL: Marquardt lambda
      real*8 COVAR(67,67),ALPHA(67,67)    ! LOCAL: Covariance etc matrix
      real*8 OCHISQ                       ! LOCAL: Previous chi-squared
      integer i,j,NVARY                   ! LOCAL: helpful integers
      integer CLDTYPE(2),CDTYPE(999999)   ! COMMON: for EBOP subroutine
      integer CNSINE,CPSINE(5)
      integer CNPOLY,CPPOLY(5)
      real*8 CNINTERVAL
      integer CNUMINT

      common / FOREBOP / CLDTYPE,CNSINE,CPSINE,CNPOLY,CPPOLY,CDTYPE,
     $                                                CNUMINT,CNINTERVAL
      ERROR = 0
!       CHISQ = 0.0d0

      CLDTYPE(1) = LDTYPE(1)
      CLDTYPE(2) = LDTYPE(2)
      do i = 1,NDATA
        CDTYPE(i) = DTYPE(i)
      end do
      CNSINE = NSINE
      CNPOLY = NPOLY
      do i = 1,5
        CPSINE(i) = PSINE(i)
        CPPOLY(i) = PPOLY(i)
      end do
      CNUMINT = NUMINT
      CNINTERVAL = NINTERVAL

      do i = 1,NDATA
        X(i)   = DATA(1,i)
        Y(i)   = DATA(2,i)
        SIG(i) = abs(DATA(3,i))
      end do

      NVARY = 0
      do i = 1,67
        if ( VARY(i) == 1 .or. VARY(i) == 3 ) NVARY = NVARY + 1
      end do

            ! Now find the best fit using MRQMIN. This requires an init-
            ! ial call with LAMBDA less than zero to initialise things.
            ! Then iterate to the best fit and assume this has been got
            ! once LAMBDA > 10^7. If no observational errors have been
            ! supplied then calculate them and send in once more. And
            ! finally set LAMBDA = 0.0 to get useful parameters out.

      LAMBDA = -1.0d0

      CALL MRQMIN (X,Y,SIG,NDATA,V,VARY,67,COVAR,ALPHA,67,CHISQ,
     &                                                     LAMBDA,ERROR)
      OCHISQ = 1.0d10

      do i = 1,50
        CALL MRQMIN (X,Y,SIG,NDATA,V,VARY,67,COVAR,ALPHA,67,CHISQ,
     &                                                     LAMBDA,ERROR)
        if ( LAMBDA >= 1.0d10 .and. abs(OCHISQ/CHISQ) < 1.001 ) exit
        if ( ERROR /= 0 ) exit
        OCHISQ = CHISQ
      end do
      ITER = i

      LAMBDA = 0.0d0
      CALL MRQMIN (X,Y,SIG,NDATA,V,VARY,67,COVAR,ALPHA,67,CHISQ,
     &                                                     LAMBDA,ERROR)

            ! Now record the formal errors outputted by MRQMIN

      do i = 1,67
        VERR(i) = sqrt(COVAR(i,i))
        if (DATA(3,1) < 0.0d0) VERR(i)=VERR(i)*sqrt(CHISQ/(NDATA-NVARY))
      end do

      if ( V(6) > 90.0d0 ) V(6) = 180.0d0 - V(6)

      if ( LDTYPE(2) == 0 ) then
        V(5) = V(4)
        VERR(5) = VERR(4)
        V(22) = V(21)
        VERR(22) = VERR(21)
      end if

      if ( DATA(3,1) > 0.0d0 )  CHISQ = CHISQ / (NDATA-NVARY)
      if ( DATA(3,1) <= 0.0d0 ) CHISQ = -1.0d0
