;+
; NAME:
;   EXOMOP_CHI2
;
; PURPOSE: 
;   Computes the chi2 for a transit 
;
; CALLING SEQUENCE:
;    chi2 = exomop_chi2(pars)
;
; INPUTS:
;	BESTPARS    - Array of the best-fit parameters 
;	DETERMINANT - The determinant of the parameterization above and
;                  the uniform priors we wish to impose. In this case,
;                  it is always 1d0 (but is required by EXOFAST_DEMC).
;
; OPTIONAL OUTPUTS:
;    transitchi2 - Chi-Squared of the best-fit parameters	
;    MODELFLUX   - The model light curve at each time (transit.time).
;   
; RESULT:
;    The chi^2 of the model given the data and parameters.
;
; COMMON BLOCKS:
;   CHI2_BLOCK - 
;   COMMON chi2_block,transit
;
; MODIFICATION HISTORY
; 2013/03/23     Jake Turner (LPL) 
;		 Created 

function exomop_chi2, bestpars, determinant=determinant,modelflux=modelflux

;common block
COMMON chi2_block,transit

transitchi2 = 0.d0
determinant = 1d0

;res = fltarr(n_elements(transit.flux))

;;find model fit
modelflux  = model_fit(transit.time, bestpars)  
 
;for i=0,n_elements(model_flux)-1 do begin 
;	res[i] = modelflux[i] - transit.flux[i] 
;endfor

;s_res = stdev(res)
 
;; chi^2
transitchi2 = total(((transit.flux - modelflux)/transit.err)^2)

return, transitchi2

end

