;+
; NAME:
;   EXOMOP_prayer
;
; PURPOSE: 
; 	Uses the Prayer Bead Method (Residual-Permutation Method) to access 
;     	 the influence of red noise. 
;	This code uses the techniques by Todorov et al 2012 (APJ,746,111) to find the 
;	 error of a non-Gaussian distribution.  
;	
; INPUTS:
;	PARS: 	Individual fitted parameters from Residual-Permutation method performed 
;		on the data
;
;OUTPUTS:
; 	histogram.ps 	- Histogram of the best-fit pars 
;	Upper_Error	- The upper error bar on the fitted parameter
;	Lower_Error 	- The lower error bar on the fitted parameter		
;	
; MODIFICATION HISTORY
; 2013/04/23     Jake Turner (LPL) 
;		 Created 
 
pro exomop_prayer,pars,name,upper_error=upper_error,lower_error=lower_error

;find size of parameter list
size = n_elements(PARS)
print,size

;sort parameters in order 
sort_par = pars[sort(pars)]
print,'Standard deviation of the par array: ',stddev(pars)

;;Error bars are going to be 34% of total number of points. 

;find closest index to zero
mid = where(abs(sort_par) eq min(abs(sort_par)))

sixeight = 0.68D*size
;;Ceil rounds up no 

halfsixeight = ceil(sixeight/2d0)
print,'index upper error ',(halfsixeight + mid)
print,'index lower error ',(mid - halfsixeight)
upper_error = sort_par(halfsixeight + mid)
lower_error = sort_par(mid - halfsixeight)

;Upper boundary constraint
If (halfsixeight + mid) gt size-1 then begin
   upper_error = sort_par(size-1)
endif

:Lower boundary constraint
If (mid - halfsixeight) lt 1 then begin
   lower_error = sort_par(0) 
endif 

;print, upper_error
;print, lower_error

;errors = fltarr(2,1)
;openw,2,'prayer_errors.dat'
;errors[0,0] = upper_error
;errors[1,0] = lower_error
;printf,2,errors
;close,2

;plot
set_plot,'ps'
device,filename=name,/color
color_array=['navy blue','red','orange','green','blue','purple', 'white', 'yellow','black']
hist,pars,XTITLE= Difference
oplot,[upper_error,upper_error],[0,200],linestyle=2,color=Fsc_Color(color_array[1]),thick=5
oplot,[lower_error,lower_error],[0,200],linestyle=2,color=Fsc_Color(color_array[1]),thick=5
oplot,[0,0],[0,200],color=Fsc_Color(color_array[8]),thick=5
device,/close

end 


