; docformat = 'rst'
;+
; This is an example program to demonstrate how to create a histogram plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "histogram_plot.pro" and run it like this::
;       IDL> .RUN histogram_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 23 January 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO Histogram_Plot
 
   ; Example data.
   data = RandomU(5L, 200)*20
   moredata = RandomU(3L, 80)*20
   
   ; Four histogram plots.
   !P.Multi = [0, 2, 2]
   
   ; Draw basic histogram plot.
   cgHistoplot, data, BINSIZE=1.0
   
   ; Same histogram plot, but with alternating color fill.
   cgHistoplot, data, BINSIZE=1.0, /FILL, POLYCOLOR=['charcoal', 'dodger blue']
   
   ; Same histogram plot, but insteadl of color fill, use line fill at 45 degrees.
   cgHistoplot, data, BINSIZE=1.0, /LINE_FILL, POLYCOLOR=['charcoal', 'dodger blue'], $
       ORIENTATION=[45, -45]
       
   ; Overlapping histograms on the same plot. Use the OPLOT keyword.   
   cgHistoplot, data, BINSIZE=1.0, /FILL, POLYCOLOR='sky blue', MININPUT=0.0
   cgHistoplot, moredata, BINSIZE=1.0, /FILL, POLYCOLOR='royal blue', MININPUT=0.0, /OPLOT
   
   ; Clean-up.
   !P.Multi = 0      
    
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  Histogram_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'Histogram_Plot', WBackground='White', $
     WTitle='Histogram Plot in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  PS_Start, 'histogram_plot.ps'
  Histogram_Plot
  PS_End
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'histogram_plot.ps', /PNG, Width=600

END