;NAME: 
; 	model_fit
;PURPOSE:
; This function uses exofast_occultquad (Mandel & Algol 2002) 
; to find a model fit with the input parameters  
; To be used in EXOMOP.pro but can be used separately. 
;
;INPUT: 
;        time (HJD) 
;        input_parameters (Rp/R*,a/R*,I,mid,lin,quad,period)
;OUPUT:  flux_model (model fit of input_parameters)
;
;MODIFICATION HISTORY
;
; 2/13/13 --- Jake Turner (LPL) 2013 
; 		program created
; 3/18/13 --- Jake Turner 
;               Can now include eccentricity and omega in the fit 


function model_fit,time,fit_start
pi =!PI


rp 		= fit_start[0] 
a_rstar		= fit_start[1] 
incl 		= fit_start[2]
mid_transit 	= fit_start[3] 
linlimb 	= fit_start[4]
quadlimb       	= fit_start[5]
period 		= fit_start[6]
ecc		= fit_start[7]
omega		= fit_start[8]


;non_circular 
If (ecc ne 0 and omega ne 0) then begin
	phase = exofast_getphase(ecc,omega,/primary)	;find phase at primary transit
	tp = mid_transit - period*phase			;find time of periastron
	z_new = exofast_getb(time,i=incl,a=a_rstar,tperiastron=tp,Period=period,e=ecc,omega=omega)
	exofast_occultquad,z_new,linlimb,quadlimb,rp,flux_model,F0	;FASTER!!
endif

;assume circular
If (ecc eq 0 and omega eq 0) then begin
	time2 = time - mid_transit	;update time
	z =a_rstar*sqrt( sin( ( (2*pi)/period)*time2)^2 + ( cos(incl) *cos( ((2*pi)/period) *time2))^2 )
	exofast_occultquad,z,linlimb,quadlimb,rp,flux_model,F0	;FASTER!!
endif 

return,flux_model
end
