pro mrd_read_image, unit, range, rsize, table 
 
; Read in the table information. 
; 
; Unit          Unit to read data from. 
; Table         Table/array to read information into. 
; 

on_error, 2

; If necessary skip to beginning of desired data. 


if range(0) gt 0 then begin 
        point_lun,-unit, cpos 
        point_lun, unit, cpos + range(0)*rsize 
endif 
 
if rsize eq 0 then return 
readu, unit, table 
ieee_to_host, table 
end 
 
pro mrd_image, header, range, rsize, table, scales, offsets, scaling, $
  status, silent=silent, tempdir=tempdir
 
; Define structure/array to hold a FITS image. 
; 
; Header                FITS header for table. 
; Range                 Range of data to be retrieved. 
; Rsize                 Size of a row or group. 
; Table                 Structure to be defined. 
; Status                ; Silent=silent		Suppress info messages?
 
on_error, 2

lens = [1,2,4,4,8] 
typstrs=['Byte', 'Int*2', 'Int*4', 'Real*4', 'Real*8']
 
status = 0 
 
 
naxis = fxpar(header, 'NAXIS') 
bitpix= fxpar(header, 'BITPIX') 
if naxis gt 0 then dims = fxpar(header, 'NAXIS*') else dims = 0 
gcount = fxpar(header, 'GCOUNT') 
pcount = fxpar(header, 'PCOUNT')
gcount = long(gcount)
 
if bitpix eq 8 then type = 0            $ 
else if bitpix eq 16 then type = 1      $ 
else if bitpix eq 32 then type = 2      $ 
else if bitpix eq -32 then type = 3     $ 
else if bitpix eq -64 then type = 4 
 
; Note that for random groups data we must ignore the first NAXISn keyword. 
if pcount gt 1 then begin 
 
        if range(0) eq -1 then begin 
                range(0) = 0 
                range(1) = gcount 
        endif 
         
        naxis = naxis - 1 
        if naxis le 0 then begin 
                rsize = 0 
                table = 0 
                return 
        endif 
         
        scales = dblarr(pcount+1)
        offsets = dblarr(pcount+1)
        dims = dims(1:naxis) 
        values = strarr(2)         
        typarr=["bytarr", "intarr", "lonarr", "fltarr", "dblarr"] 
        values(0) = typarr(type) + "("+string(pcount)+")" 
        rsize = dims(0) 
        sarr = "(" + strcompress(string(dims(0)))
         
        for i=1, naxis-1 do begin 
                sarr = sarr + "," + strcompress(string(dims(i)),/remo)
                rsize = rsize*dims(i) 
        endfor 
         
        sarr = sarr + ")"

	if not keyword_set(silent) then print,'MRDFITS--Image with groups:', $
	  ' Groups=',strcompress(string(gcount)),' Npar=', 		     $
	  strcompress(string(pcount)), ' Array=', sarr, '  Type=',typstrs(type)

	sarr = typarr(type) + sarr
        values(1) = sarr 
        rsize = (rsize + pcount)*lens(type) 
         
        table = mrd_struct(['params','array'], values, range(1)-range(0)+1, $
	  tempdir=tempdir)
	   
    
	
        for i=0, pcount-1 do begin
                istr = strcompress(string(i),/remo)
                scales(i) = fxpar(header, 'PSCAL'+istr)
                if scales(i) eq 0.0d0 then scales(i) =1.0d0
                offsets(i) = fxpar(header, 'PZERO'+istr)
                scales(pcount) = fxpar(header, 'BSCALE')
                if scales(pcount) eq 0.0d0 then scales(pcount) = 1.0d0
                offsets(pcount) = fxpar(header, 'BOFFSET')
        endfor
        if scaling then begin
                w = where(scales ne 1.0d0 or offsets ne 0.0d0)
                if w(0) eq -1 then scaling = 0
        endif
endif else begin 
 
        if naxis eq 0 then begin 
                rsize = 0 
                table = 0
		if not keyword_set(silent) then begin
			print, 'MRDFITS: Null image, NAXIS=0'
		endif
                return 
        endif 
         
        if gcount gt 1 then begin 
                dims = [dims, gcount] 
                naxis = naxis + 1 
        endif 
         
         
        for i=naxis-1,1,-1 do begin 
                if dims(i) eq 1 then begin
			if not keyword_set(silent) then begin
				print, 'MRDFITS: Truncating unused dimensions'
			endif
                        dims = dims(0:i-1) 
                        naxis = naxis - 1 
                endif else begin 
                        goto, no_trunc 
                endelse 
        endfor 
 
no_trunc:
	if not keyword_set(silent) then begin
		str = '('
		for i=0, naxis-1 do begin
			if i ne 0 then str = str + ','
			str = str + strcompress(string(dims(i)),/remo)
		endfor
		str = str+')'
		print, 'MRDFITS: Image array ',str, '  Type=', typstrs(type)
	endif
		
        maxd = dims(naxis-1) 
         
        if range(0) ne -1 then begin 
                range(0) = range(0)<(maxd-1) 
                range(1) = range(1)<(maxd-1) 
        endif else begin 
                range(0) = 0 
                range(1) = maxd - 1 
        endelse 
         
        dims(naxis-1) = range(1)-range(0)+1 
         
        rsize = 1 
        if naxis gt 1 then for i=0, naxis - 2 do rsize=rsize*dims(i) 
        rsize = rsize*lens(type) 
         
        sz = lonarr(naxis+3) 
        sz(0) = naxis 
        sz(1:naxis) = dims 
        nele = 1l 
         
        for i=0, naxis-1 do begin 
                nele = nele*dims(i) 
        endfor 
         
        sz(naxis+1) = type + 1   
        sz(naxis+2) = nele 
         
        if nele gt 0 then  begin 
                table = make_array(size=sz) 
        endif else begin 
                table = 0 
        endelse 
        
        scales = dblarr(1)
        offsets = dblarr(1)
        scales(0) = fxpar(header, 'BSCALE')
        offsets(0) = fxpar(header, 'BOFFSET')
        if scales(0) eq 0.0d0 then scales(0) = 1.0d0
        if scaling and scales(0) eq 1.0d0 and offsets(0) eq 0.0d0 then $
            scaling = 0
         
endelse 
         
status = 0 
return 
 
end 